qhat_mlogit: Estimate marginal and joint distribution of lists j and k using multinomial logistic model.
Description
Estimate marginal and joint distribution of lists j and k using multinomial logistic model.
Usage
qhat_mlogit(List.train, List.test, K = 2, j = 1, k = 2, margin = 0.005, ...)
Arguments
List.train
The training data matrix used to estimate the distibution functions.
List.test
The data matrix on which the estimator function is applied.
K
The number of lists in the data.
j
The first list that is conditionally independent.
k
The second list that is conditionally independent.
margin
The minimum value the estimates can attain to bound them away from zero.
...
Any extra arguments passed into the function.
Value
A list of the marginal and joint distribution probabilities q1, q2 and q12.
References
Croissant Y (2020). Estimation of Random Utility Models in R: The mlogit Package. Journal of Statistical Software, 95(11), 1-41. doi: 10.18637/jss.v095.i11 (URL: https://doi.org/10.18637/jss.v095.i11).
Venables, W. N. & Ripley, B. D. (2002) Modern Applied Statistics with S. Fourth Edition. Springer, New York. ISBN 0-387-95457-0