qhat_ranger: Estimate marginal and joint distribution of lists j and k using ranger.
Description
Estimate marginal and joint distribution of lists j and k using ranger.
Usage
qhat_ranger(List.train, List.test, K = 2, j = 1, k = 2, margin = 0.005, ...)
Arguments
List.train
The training data matrix used to estimate the distibution functions.
List.test
The data matrix on which the estimator function is applied.
K
The number of lists in the data.
j
The first list that is conditionally independent.
k
The second list that is conditionally independent.
margin
The minimum value the estimates can attain to bound them away from zero.
...
Any extra arguments passed into the function.
Value
A list of the marginal and joint distribution probabilities q1, q2 and q12.
References
Marvin N. Wright, Andreas Ziegler (2017). ranger: A Fast Implementation of Random Forests for High Dimensional Data in C++ and R. Journal of Statistical Software, 77(1), 1-17. doi:10.18637/jss.v077.i01