The number of cores to be used for paralellization in Super Learner.
...
Any extra arguments passed into the function.
Value
A list of the marginal and joint distribution probabilities q1, q2 and q12.
References
Eric Polley, Erin LeDell, Chris Kennedy and Mark van der Laan (2021). SuperLearner: Super Learner Prediction. R package version 2.0-28. https://CRAN.R-project.org/package=SuperLearner
van der Laan, M. J., Polley, E. C. and Hubbard, A. E. (2008) Super Learner, Statistical Applications of Genetics and Molecular Biology, 6, article 25.